<p align="center" width="100%">
    <img src="https://raw.githubusercontent.com/ro-py/ro.py/main/resources/textlogo.svg" alt="ro.py" height="128em" />
    <br />
</p>
<p align="center">
    <a href="https://github.com/ro-py/ro.py">GitHub</a> |
    <a href="https://discord.gg/UKPaPu4teg">Discord</a> |
    <a href="https://pypi.org/project/roblox/">PyPI</a> |
    <a href="https://ro.py.jmk.gg/">Documentation</a> |
    <a href="https://github.com/ro-py/ro.py/tree/main/examples">Examples</a> |
    <a href="https://github.com/ro-py/ro.py/blob/main/LICENSE">License</a>
</p>
<p align="center">
    <a href="https://discord.gg/UKPaPu4teg"><img src="https://img.shields.io/discord/761603917490159676?style=flat-square&logo=discord" alt="RoAPI Discord"/></a>
    <a href="https://pypi.org/project/ro-py/"><img src="https://img.shields.io/pypi/v/roblox?style=flat-square" alt="ro.py PyPI"/></a>
    <a href="https://pypi.org/project/roblox/"><img src="https://img.shields.io/pypi/dm/roblox?style=flat-square" alt="ro.py PyPI Downloads"/></a>
    <a href="https://pypi.org/project/roblox/"><img src="https://img.shields.io/pypi/dm/ro-py?style=flat-square" alt="ro.py PyPI Downloads (Legacy)"/></a>
    <a href="https://pypi.org/project/ro-py/"><img src="https://img.shields.io/pypi/l/roblox?style=flat-square" alt="ro.py PyPI License"/></a>
    <a href="https://github.com/ro-py/ro.py"><img src="https://img.shields.io/github/commit-activity/w/rbx-libdev/ro.py?style=flat-square" alt="ro.py GitHub Commit Activity"/></a>
    <a href="https://github.com/ro-py/ro.py"><img src="https://img.shields.io/github/last-commit/rbx-libdev/ro.py?style=flat-square" alt="ro.py GitHub Last Commit"/></a>
</p>

# Overview
Welcome to pyrbx a fork of ro.py.
pyrbx is an asynchronous, object-oriented wrapper for the Roblox web API.

This fork main purpose is to implement support for Roblox Cloud APIs, however other features are also being added.

The table below represents full support of cloud services.

| Service          | Completed |
|------------------|---|
| Messaging        | ✅ |
| Data Stores      | ❌ |
| Place Publishing | ❌ |
| Assets           | ❌ |

# Features
The key features are:  

- **Asynchronous**: ro.py works well with asynchronous frameworks like [FastAPI](https://fastapi.tiangolo.com/) and 
[discord.py](https://github.com/Rapptz/discord.py).  
- **Easy**: ro.py's client-based model is intuitive and easy to learn for both the beginner and expert developer. It
  abstracts away API requests and leaves you with simple objects that represent data types on the Roblox platform.
- **Flexible**: ro.py's builtin Requests object allows the user to do things that we haven't already implemented
ourselves without dealing with advanced Roblox-specific concepts.

# Installation
To install ro.py from PyPI, you can install with pip:
```
pip install roblox
```

To install the latest unstable version of ro.py, install [git-scm](https://git-scm.com/downloads) and run the following:
```
pip install git+https://github.com/ro-py/ro.py.git
```

# Tutorial
Learn how to use ro.py in our docs:
https://anyastrophic.github.io/pyrbx/dev/